<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-position="left" label-width="50px">
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="料号" prop="itemNumber">
            <el-input
              v-model="queryParams.itemNumber"
              placeholder="请输入料号"
              clearable
              @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <!-- <el-col :span="18" style="text-align: right;">
          <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
              <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-col> -->
      </el-row>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <right-toolbar v-model:showSearch="showSearch" 
        @queryTable="handleQuery"
        @resetTable="resetQuery"
      ></right-toolbar>
    </el-row>

    <HxlhTable
        style="width: 100%"
        :columns="columns"
        :data="materialManagementList"
        :loading="loading"
        :height="height"
        :page="page"
        @changePageNo="changePageNo"
        @changePageSize="changePageSize"
    >
    </HxlhTable>
    
  </div>
</template>

<script setup name="MaterialManagement">
import { listMaterialManagement, getMaterialManagement, delMaterialManagement, addMaterialManagement, updateMaterialManagement } from "@/api/basicData/materialManagement/materialManagement";
import HxlhTable from '@/components/HxlhTable'
import { listAll_plant } from "@/api/basicData/plant";
import { listAll_shop } from "@/api/basicData/shop";
import { status } from "nprogress";
import { onMounted } from "vue";
import axios from 'axios';

const { proxy } = getCurrentInstance();

const { aps_material_status } = proxy.useDict('aps_material_status');
const { aps_professional_affiliation } = proxy.useDict('aps_professional_affiliation');
const { aps_self_made } = proxy.useDict('aps_self_made');
const materialManagementList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");
const height = ref(document.documentElement.clientHeight - 210 + "px;")

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    itemNumber: null,
  },
  rules: {
  }
});

// 表格配置 
const columns = ref([
  { type: 'seq', title: '序号', width: 60 },
  {
    title: '料号',
    field: 'itemNumber',
    width: 150,
  },
  {
    title: '物料描述',
    field: 'materialDescription',
    width: 150,
  },
  {
    title: '物料状态',
    field: 'materialStatus',
    width: 150,
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<aps_material_status.value.length;i++){
          if(cellValue===aps_material_status.value[i].value){
            return aps_material_status.value[i].label
          }
        }
      }
      return '';
    })
  },
  {
    title: '物料类型',
    field: 'materialType',
    width: 150,
  },
  {
    title: '专业归属',
    field: 'professionalAffiliation',
    width: 150,
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<aps_professional_affiliation.value.length;i++){
          if(cellValue===aps_professional_affiliation.value[i].value){
            return aps_professional_affiliation.value[i].label
          }
        }
      }
      return '';
    })
  },
  {
    title: '图号',
    field: 'drawingNo',
    width: 150,
  },
  {
    title: '版本',
    field: 'versionNumber',
    width: 150,
  },
  {
    title: '最早可提前生产天数',
    field: 'advanceProductionDays',
    width: 150,
  },
  {
    title: '拆分批量',
    field: 'splitBatch',
    width: 100,
  },
  {
    title: '是否自制',
    field: 'selfMade',
    width: 80,
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<aps_self_made.value.length;i++){
          if(cellValue===aps_self_made.value[i].value){
            return aps_self_made.value[i].label
          }
        }
      }
      return '';
    })
  },
  {
    title: '适用工厂',
    field: 'applicableFactories',
    width: 150,
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<plantList.value.length;i++){
          if(cellValue===plantList.value[i].plantCode){
            return plantList.value[i].plantName
          }
        }
      }
      return '';
    })
  },
  {
    title: '适用车间',
    field: 'applicableWorkshop',
    width: 150,
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        console.log(apsShopList.value);
        for(let i=0;i<apsShopList.value.length;i++){
          if(cellValue===apsShopList.value[i].shopCode){
            return apsShopList.value[i].shopCode
          }
        }
      }
      return '';
    })
  },
  {
    title: '生效日期',
    field: 'effectiveDate',
    width: 100,
  },
  {
    title: '失效日期',
    field: 'expiringDate',
    width: 100,
  },
  {
    title: '集成日期',
    field: 'integrationDate',
    width: 100,
  },
]);

const { queryParams, form, rules } = toRefs(data);

const queryPlants = ref({status: 1});
const plantList = ref([]);
const queryApsShops = ref({status: 1});
const apsShopList = ref([]);

// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10
});

/** 查询物料管理列表 */
function getList() {
  loading.value = true;
  axios.all([
      /** 查询工厂列表 */
      listAll_plant(queryPlants.value),
      /** 查询车间列表 */
      listAll_shop(queryApsShops.value),
      listMaterialManagement(queryParams.value)
    ])
    .then(axios.spread((response1, response2, response3) => {
      plantList.value = response1.data;
      apsShopList.value = response2.data;
      materialManagementList.value = response3.rows;
      page.value.total = response3.total;
      loading.value = false;
    }))
    .catch(error => {
      console.error('请求出错:', error);
    });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    itemNumber: null,
    materialDescription: null,
    materialStatus: null,
    materialType: null,
    professionalAffiliation: null,
    drawingNo: null,
    versionNumber: null,
    advanceProductionDays: null,
    splitBatch: null,
    selfMade: null,
    applicableFactories: null,
    applicableWorkshop: null,
    effectiveDate: null,
    expiringDate: null,
    integrationDate: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null
  };
  proxy.resetForm("materialManagementRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加物料管理";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value
  getMaterialManagement(_id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改物料管理";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["materialManagementRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateMaterialManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addMaterialManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除物料管理编号为"' + _ids + '"的数据项？').then(function() {
    return delMaterialManagement(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('materialManagement/materialManagement/export', {
    ...queryParams.value
  }, `materialManagement_${new Date().getTime()}.xlsx`)
}

function changePageNo(currentPage) {
  queryParams.value.pageNum = currentPage;
  page.value.current = currentPage;
  getList();
}

function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}

getList();
</script>
